Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1920)

Unified Diff: cc/trees/layer_tree_host_unittest_copyrequest.cc

Issue 2337913003: Fork cc::OutputSurface into cc::CompositorFrameSink. (Closed)
Patch Set: cfsfork: android-vulkan Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/trees/layer_tree_host_unittest_context.cc ('k') | cc/trees/layer_tree_host_unittest_remote_server.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/trees/layer_tree_host_unittest_copyrequest.cc
diff --git a/cc/trees/layer_tree_host_unittest_copyrequest.cc b/cc/trees/layer_tree_host_unittest_copyrequest.cc
index 5867452ab4fd676053e4d876d64a4db13c445511..50c8b621f4fd5320b5df2b38521fcdc4aff3a6a0 100644
--- a/cc/trees/layer_tree_host_unittest_copyrequest.cc
+++ b/cc/trees/layer_tree_host_unittest_copyrequest.cc
@@ -17,7 +17,7 @@
#include "cc/test/fake_output_surface.h"
#include "cc/test/fake_picture_layer.h"
#include "cc/test/layer_tree_test.h"
-#include "cc/test/test_delegating_output_surface.h"
+#include "cc/test/test_compositor_frame_sink.h"
#include "cc/trees/layer_tree_impl.h"
#include "gpu/GLES2/gl2extchromium.h"
@@ -463,10 +463,10 @@ class LayerTreeHostTestHiddenSurfaceNotAllocatedForSubtreeCopyRequest
client_.set_bounds(root_->bounds());
}
- std::unique_ptr<TestDelegatingOutputSurface> CreateDelegatingOutputSurface(
+ std::unique_ptr<TestCompositorFrameSink> CreateCompositorFrameSink(
scoped_refptr<ContextProvider> compositor_context_provider,
scoped_refptr<ContextProvider> worker_context_provider) override {
- auto surface = LayerTreeHostCopyRequestTest::CreateDelegatingOutputSurface(
+ auto surface = LayerTreeHostCopyRequestTest::CreateCompositorFrameSink(
std::move(compositor_context_provider),
std::move(worker_context_provider));
display_ = surface->display();
@@ -852,7 +852,7 @@ class LayerTreeHostCopyRequestTestCountTextures
// These tests expect the LayerTreeHostImpl to share a context with
// the Display so that sync points are not needed and the texture counts
// are visible together.
// Since this test does not override CreateDelegatingOutputSurface, the
// |compositor_context_provider| will be a TestContextProvider.
display_context_provider_ =
static_cast<TestContextProvider*>(compositor_context_provider.get());
@@ -852,7 +852,7 @@ class LayerTreeHostCopyRequestTestCountTextures
// the Display so that sync points are not needed and the texture counts
// are visible together.
- // Since this test does not override CreateDelegatingOutputSurface, the
+ // Since this test does not override CreateCompositorFrameSink, the
// |compositor_context_provider| will be a TestContextProvider.
display_context_provider_ =
« no previous file with comments | « cc/trees/layer_tree_host_unittest_context.cc ('k') | cc/trees/layer_tree_host_unittest_remote_server.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698